@@ -5,10 +5,29 @@
 
 # nocov start
 make_discrim_flexible <- function() {
-  parsnip::set_model_engine("discrim_flexible", "classification", "earth")
-  parsnip::set_dependency("discrim_flexible", eng = "earth", pkg = "mda")
-  parsnip::set_dependency("discrim_flexible", eng = "earth", pkg = "earth")
-  parsnip::set_dependency("discrim_flexible", eng = "earth", pkg = "discrim")
+  parsnip::set_model_engine(
+    model = "discrim_flexible",
+    mode = "classification",
+    eng = "earth"
+  )
+  parsnip::set_dependency(
+    model = "discrim_flexible",
+    eng = "earth",
+    pkg = "mda",
+    mode = "classification"
+  )
+  parsnip::set_dependency(
+    model = "discrim_flexible",
+    eng = "earth",
+    pkg = "earth",
+    mode = "classification"
+  )
+  parsnip::set_dependency(
+    model = "discrim_flexible",
+    eng = "earth",
+    pkg = "discrim",
+    mode = "classification"
+  )
 
   parsnip::set_model_arg(
     model = "discrim_flexible",
@@ -16,7 +35,7 @@ make_discrim_flexible <- function() {
     parsnip = "num_terms",
     original = "nprune",
     func = list(pkg = "dials", fun = "num_terms"),
-    has_submodel = TRUE
+    has_submodel = FALSE
   )
   parsnip::set_model_arg(
     model = "discrim_flexible",
