@@ -11,8 +11,18 @@
 
 make_discrim_linear_MASS <- function() {
   parsnip::set_model_engine("discrim_linear", "classification", "MASS")
-  parsnip::set_dependency("discrim_linear", "MASS", "MASS")
-  parsnip::set_dependency("discrim_linear", "MASS", "discrim")
+  parsnip::set_dependency(
+    "discrim_linear",
+    "MASS",
+    "MASS",
+    mode = "classification"
+  )
+  parsnip::set_dependency(
+    "discrim_linear",
+    "MASS",
+    "discrim",
+    mode = "classification"
+  )
 
   parsnip::set_fit(
     model = "discrim_linear",
@@ -90,9 +100,23 @@ make_discrim_linear_MASS <- function() {
 # ------------------------------------------------------------------------------
 
 make_discrim_linear_mda <- function() {
-  parsnip::set_model_engine("discrim_linear", "classification", "mda")
-  parsnip::set_dependency("discrim_linear", eng = "mda", pkg = "mda")
-  parsnip::set_dependency("discrim_linear", eng = "mda", pkg = "discrim")
+  parsnip::set_model_engine(
+    model = "discrim_linear",
+    mode = "classification",
+    eng = "mda"
+  )
+  parsnip::set_dependency(
+    model = "discrim_linear",
+    eng = "mda",
+    pkg = "mda",
+    mode = "classification"
+  )
+  parsnip::set_dependency(
+    model = "discrim_linear",
+    eng = "mda",
+    pkg = "discrim",
+    mode = "classification"
+  )
 
   parsnip::set_model_arg(
     model = "discrim_linear",
@@ -180,9 +204,23 @@ make_discrim_linear_mda <- function() {
 # ------------------------------------------------------------------------------
 
 make_discrim_linear_sda <- function() {
-  parsnip::set_model_engine("discrim_linear", "classification", "sda")
-  parsnip::set_dependency("discrim_linear", "sda", "sda")
-  parsnip::set_dependency("discrim_linear", "sda", "discrim")
+  parsnip::set_model_engine(
+    model = "discrim_linear",
+    mode = "classification",
+    eng = "sda"
+  )
+  parsnip::set_dependency(
+    model = "discrim_linear",
+    eng = "sda",
+    pkg = "sda",
+    mode = "classification"
+  )
+  parsnip::set_dependency(
+    model = "discrim_linear",
+    eng = "sda",
+    pkg = "discrim",
+    mode = "classification"
+  )
 
   parsnip::set_fit(
     model = "discrim_linear",
@@ -265,9 +303,23 @@ make_discrim_linear_sda <- function() {
 # ------------------------------------------------------------------------------
 
 make_discrim_linear_sparsediscrim <- function() {
-  parsnip::set_model_engine("discrim_linear", "classification", "sparsediscrim")
-  parsnip::set_dependency("discrim_linear", "sparsediscrim", "sparsediscrim")
-  parsnip::set_dependency("discrim_linear", "sparsediscrim", "discrim")
+  parsnip::set_model_engine(
+    model = "discrim_linear",
+    mode = "classification",
+    eng = "sparsediscrim"
+  )
+  parsnip::set_dependency(
+    model = "discrim_linear",
+    eng = "sparsediscrim",
+    pkg = "sparsediscrim",
+    mode = "classification"
+  )
+  parsnip::set_dependency(
+    model = "discrim_linear",
+    eng = "sparsediscrim",
+    pkg = "discrim",
+    mode = "classification"
+  )
 
   parsnip::set_fit(
     model = "discrim_linear",
